@@ -17,16 +17,15 @@
 #include <algorithm>
 #include <stdexcept>
 #include <shlwapi.h>
-#include <uxtheme.h>
-#include <cassert>
+#include <commctrl.h>
 #include <locale>
 #include "StaticDialog.h"
 #include "CustomFileDialog.h"
 #include "FileInterface.h"
 #include "Common.h"
 #include "Utf8.h"
-#include "Parameters.h"
 #include "Buffer.h"
+#include "dpiManagerV2.h"
 
 using namespace std;
 
@@ -282,7 +281,7 @@ bool isInList(const wchar_t *token, const wchar_t *list)
 				word[j] = '\0';
 				j = 0;
 
-				if (!wcsicmp(token, word))
+				if (!_wcsicmp(token, word))
 					return true;
 			}
 		}
@@ -1513,20 +1512,15 @@ wstring getDateTimeStrFrom(const wstring& dateTimeFormat, const SYSTEMTIME& st)
 // Don't forget to use DeleteObject(createdFont) before leaving the program
 HFONT createFont(const wchar_t* fontName, int fontSize, bool isBold, HWND hDestParent)
 {
-	HDC hdc = GetDC(hDestParent);
-
 	LOGFONT logFont{};
-	logFont.lfHeight = DPIManagerV2::scaleFont(fontSize, hDestParent);
+	const int fontSizeScaled = DPIManagerV2::scaleFontForFactor(fontSize);
+	logFont.lfHeight = DPIManagerV2::scaleFont(fontSizeScaled, hDestParent);
 	if (isBold)
 		logFont.lfWeight = FW_BOLD;
 
-	wcscpy_s(logFont.lfFaceName, fontName);
+	::wcsncpy_s(logFont.lfFaceName, fontName, size_t{ LF_FACESIZE - 1 });
 
-	HFONT newFont = CreateFontIndirect(&logFont);
-
-	ReleaseDC(hDestParent, hdc);
-
-	return newFont;
+	return ::CreateFontIndirectW(&logFont);
 }
 
 bool removeReadOnlyFlagFromFileAttributes(const wchar_t* fileFullPath)
@@ -1890,7 +1884,7 @@ struct GetDiskFreeSpaceParamResult
 	BOOL _result = FALSE;
 	bool _isTimeoutReached = true;
 
-	GetDiskFreeSpaceParamResult(wstring dirPath) : _dirPath(dirPath) {};
+	GetDiskFreeSpaceParamResult(wstring dirPath) : _dirPath(dirPath) {}
 };
 
 DWORD WINAPI getDiskFreeSpaceExWorker(void* data)
@@ -1899,7 +1893,7 @@ DWORD WINAPI getDiskFreeSpaceExWorker(void* data)
 	inAndOut->_result = ::GetDiskFreeSpaceExW(inAndOut->_dirPath.c_str(), &(inAndOut->_freeBytesForUser), nullptr, nullptr);
 	inAndOut->_isTimeoutReached = false;
 	return ERROR_SUCCESS;
-};
+}
 
 BOOL getDiskFreeSpaceWithTimeout(const wchar_t* dirPath, ULARGE_INTEGER* freeBytesForUser, DWORD milliSec2wait, bool* isTimeoutReached)
 {
@@ -1960,7 +1954,7 @@ DWORD WINAPI getFileAttributesExWorker(void* data)
 		inAndOut->_error = ::GetLastError();
 	inAndOut->_isTimeoutReached = false;
 	return ERROR_SUCCESS;
-};
+}
 
 BOOL getFileAttributesExWithTimeout(const wchar_t* filePath, WIN32_FILE_ATTRIBUTE_DATA* fileAttr,
 	DWORD milliSec2wait, bool* isTimeoutReached, DWORD* pdwWin32ApiError)
@@ -2078,7 +2072,10 @@ bool isWindowVisibleOnAnyMonitor(const RECT& rectWndIn)
 	return param4InOut.isWndVisibleOut;
 }
 
+#if defined(_MSC_VER)
 #pragma warning(disable:4996) // 'GetVersionExW': was declared deprecated
+#endif
+
 bool isCoreWindows()
 {
 	bool isCoreWindows = false;
@@ -2202,7 +2199,9 @@ void ControlInfoTip::hide()
 	}
 }
 
+#if defined(_MSC_VER)
 #pragma warning(default:4996)
+#endif
 
 DWORD invokeNppUacOp(const std::wstring& strCmdLineParams)
 {
