@@ -15,6 +15,8 @@
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 #pragma once
+
+#include "NppConstants.h"
 #include <vector>
 #include <string>
 #include <sstream>
@@ -26,31 +28,12 @@
 #include <algorithm>
 #include <tchar.h>
 
+#if defined(_MSC_VER)
 #pragma deprecated(PathFileExists)  // Use doesFileExist, doesDirectoryExist or doesPathExist (for file or directory) instead.
 #pragma deprecated(PathIsDirectory) // Use doesDirectoryExist instead.
-
-
-const bool dirUp = true;
-const bool dirDown = false;
-
-#define NPP_CP_WIN_1252           1252
-#define NPP_CP_DOS_437            437
-#define NPP_CP_BIG5               950
-
-#define LINKTRIGGERED WM_USER+555
-
-#define BCKGRD_COLOR (RGB(255,102,102))
-#define TXT_COLOR    (RGB(255,255,255))
-
-#ifndef __MINGW32__
-#define WCSTOK wcstok
-#else
-#define WCSTOK wcstok_s
 #endif
 
 
-#define NPP_INTERNAL_FUNCTION_STR L"Notepad++::InternalFunction"
-
 
 std::wstring folderBrowser(HWND parent, const std::wstring & title = L"", int outputCtrlID = 0, const wchar_t *defaultStr = NULL);
 std::wstring getFolderName(HWND parent, const wchar_t *defaultDir = NULL);
@@ -90,10 +73,10 @@ public:
 
 	const wchar_t* char2wchar(const char* mbStr, size_t codepage, int lenMbcs = -1, int* pLenOut = NULL, int* pBytesNotProcessed = NULL);
 	const wchar_t* char2wchar(const char* mbcs2Convert, size_t codepage, intptr_t* mstart, intptr_t* mend, int len = 0);
-	size_t getSizeW() { return _wideCharStr.size(); };
+	size_t getSizeW() const { return _wideCharStr.size(); }
 	const char* wchar2char(const wchar_t* wcStr, size_t codepage, int lenIn = -1, int* pLenOut = NULL);
 	const char* wchar2char(const wchar_t* wcStr, size_t codepage, intptr_t* mstart, intptr_t* mend, int lenIn = 0, int* lenOut = nullptr);
-	size_t getSizeA() { return _multiByteStr.size(); };
+	size_t getSizeA() const { return _multiByteStr.size(); }
 
 	const char* encode(UINT fromCodepage, UINT toCodepage, const char* txt2Encode, int lenIn = -1, int* pLenOut = NULL, int* pBytesNotProcessed = NULL) {
 		int lenWc = 0;
@@ -154,8 +137,6 @@ protected:
 	StringBuffer<wchar_t> _wideCharStr;
 };
 
-#define REBARBAND_SIZE sizeof(REBARBANDINFO)
-
 std::wstring pathRemoveFileSpec(std::wstring & path);
 std::wstring pathAppend(std::wstring &strDest, const std::wstring & str2append);
 COLORREF getCtrlBgColor(HWND hWnd);
@@ -233,42 +214,42 @@ class Version final
 {
 public:
 	Version() = default;
-	Version(const std::wstring& versionStr);
+	explicit Version(const std::wstring& versionStr);
 
 	void setVersionFrom(const std::wstring& filePath);
 	std::wstring toString();
-	bool isNumber(const std::wstring& s) const {
+	static bool isNumber(const std::wstring& s) {
 		return !s.empty() &&
-			find_if(s.begin(), s.end(), [](wchar_t c) { return !_istdigit(c); }) == s.end();
-	};
+			find_if(s.begin(), s.end(), [](wchar_t c) { return !iswdigit(c); }) == s.end();
+	}
 
 	int compareTo(const Version& v2c) const;
 
 	bool operator < (const Version& v2c) const {
 		return compareTo(v2c) == -1;
-	};
+	}
 
 	bool operator <= (const Version& v2c) const {
 		int r = compareTo(v2c);
 		return r == -1 || r == 0;
-	};
+	}
 
 	bool operator > (const Version& v2c) const {
 		return compareTo(v2c) == 1;
-	};
+	}
 
 	bool operator >= (const Version& v2c) const {
 		int r = compareTo(v2c);
 		return r == 1 || r == 0;
-	};
+	}
 
 	bool operator == (const Version& v2c) const {
 		return compareTo(v2c) == 0;
-	};
+	}
 
 	bool operator != (const Version& v2c) const {
 		return compareTo(v2c) != 0;
-	};
+	}
 
 	bool empty() const {
 		return _major == 0 && _minor == 0 && _patch == 0 && _build == 0;
@@ -300,26 +281,25 @@ bool isWindowVisibleOnAnyMonitor(const RECT& rectWndIn);
 bool isCoreWindows();
 
 
-#define IDT_HIDE_TOOLTIP 1001
-
 class ControlInfoTip final
 {
 public:
-	ControlInfoTip() {};
+	ControlInfoTip() = default;
 	~ControlInfoTip() {
 		if (_hWndInfoTip) {
 			hide();
 		}
-	};
+	}
+
 	bool init(HINSTANCE hInst, HWND ctrl2attached, HWND ctrl2attachedParent, const std::wstring& tipStr, bool isRTL, unsigned int remainTimeMillisecond = 0, int maxWidth = 200); // remainTimeMillisecond = 0: no timeout
 
 	bool isValid() const {
 		return _hWndInfoTip != nullptr;
-	};
+	}
 
 	HWND getTipHandle() const {
 		return _hWndInfoTip;
-	};
+	}
 
 	enum showPosition {beginning, middle, end};
 	void show(showPosition pos = middle) const;
@@ -334,9 +314,4 @@ private:
 	ControlInfoTip& operator=(const ControlInfoTip&) = delete;
 };
 
-
-#define NPP_UAC_SAVE_SIGN L"#UAC-SAVE#"
-#define NPP_UAC_SETFILEATTRIBUTES_SIGN L"#UAC-SETFILEATTRIBUTES#"
-#define NPP_UAC_MOVEFILE_SIGN L"#UAC-MOVEFILE#"
-#define NPP_UAC_CREATEEMPTYFILE_SIGN L"#UAC-CREATEEMPTYFILE#"
 DWORD invokeNppUacOp(const std::wstring& strCmdLineParams);
