@@ -91,6 +91,8 @@ void Notepad_plus_Window::init(HINSTANCE hInst, HWND parent, const wchar_t *cmdL
 		_notepad_plus_plus_core._pluginsManager.disable();
 
 	nppGUI._isCmdlineNosessionActivated = cmdLineParams->_isNoSession;
+	nppGUI._isFullReadOnly = cmdLineParams->_isFullReadOnly;
+	nppGUI._isFullReadOnlySavingForbidden = cmdLineParams->_isFullReadOnlySavingForbidden;
 
 	_hIconAbsent = ::LoadIcon(hInst, MAKEINTRESOURCE(IDI_ICONABSENT));
 
@@ -109,6 +111,14 @@ void Notepad_plus_Window::init(HINSTANCE hInst, HWND parent, const wchar_t *cmdL
 	if (NULL == _hSelf)
 		throw std::runtime_error("Notepad_plus_Window::init : CreateWindowEx() function return null");
 
+	if (!cmdLineParams->_pluginMessage.empty())
+	{
+		SCNotification scnN{};
+		scnN.nmhdr.code = NPPN_CMDLINEPLUGINMSG;
+		scnN.nmhdr.hwndFrom = _hSelf;
+		scnN.nmhdr.idFrom = reinterpret_cast<uptr_t>(cmdLineParams->_pluginMessage.c_str());
+		_notepad_plus_plus_core._pluginsManager.notify(&scnN);
+	}
 
 	PaintLocker paintLocker{_hSelf};
 
@@ -401,6 +411,11 @@ void Notepad_plus_Window::init(HINSTANCE hInst, HWND parent, const wchar_t *cmdL
 		::MessageBoxW(NULL, wss.str().c_str(), L"Notepad++ loading time (hh:mm:ss.ms)", MB_OK);
 	}
 
+	if (cmdLineParams->_displayCmdLineArgs)
+	{
+		_notepad_plus_plus_core.command(IDM_CMDLINEARGUMENTS);
+	}
+
 	bool isSnapshotMode = nppGUI.isSnapshotMode();
 	if (isSnapshotMode)
 	{
