@@ -231,7 +231,7 @@ class GlobalMappers
             setLexerMapper[SCE_USER_KWLIST_FOLDERS_IN_CODE1_OPEN] 	= "userDefine.foldersInCode1Open";
             setLexerMapper[SCE_USER_KWLIST_FOLDERS_IN_CODE1_MIDDLE] = "userDefine.foldersInCode1Middle";
             setLexerMapper[SCE_USER_KWLIST_FOLDERS_IN_CODE1_CLOSE] 	= "userDefine.foldersInCode1Close";
-        };
+        }
 };
 
 GlobalMappers & globalMappper();
@@ -303,57 +303,57 @@ class UserDefineDialog : public SharedParametersDialog
 friend class ScintillaEditView;
 public :
     UserDefineDialog();
-    ~UserDefineDialog();
+    ~UserDefineDialog() override;
     void init(HINSTANCE hInst, HWND hPere, ScintillaEditView *pSev) {
         if (!_pScintilla)
         {
             Window::init(hInst, hPere);
             _pScintilla = pSev;
         }
-    };
+    }
     void setScintilla(ScintillaEditView *pScinView) {
         _pScintilla = pScinView;
-    };
+    }
 
     void destroy() override {
         // A Ajouter les fils...
-    };
+    }
     int getWidth() const override {
         return _dlgPos.right;
-    };
+    }
     int getHeight() const override {
         return _dlgPos.bottom;
-    };
+    }
     void doDialog(bool willBeShown = true, bool isRTL = false) {
         if (!isCreated())
             create(IDD_GLOBAL_USERDEFINE_DLG, isRTL);
         display(willBeShown);
-    };
+    }
     void reSizeTo(RECT & rc) override// should NEVER be const !!!
     {
         Window::reSizeTo(rc);
         display(false);
         display();
-    };
+    }
     void reloadLangCombo();
     void changeStyle();
-    bool isDocked() const {return _status == DOCK;};
-    void setDockStatus(bool isDocked) {_status = isDocked;};
+    bool isDocked() const { return _status == DOCK; }
+    void setDockStatus(bool isDocked) { _status = isDocked; }
     HWND getFolderHandle() const {
         return _folderStyleDlg.getHSelf();
-    };
+    }
     HWND getKeywordsHandle() const {
         return _keyWordsStyleDlg.getHSelf();
-    };
+    }
     HWND getCommentHandle() const {
         return _commentStyleDlg.getHSelf();
-    };
+    }
     HWND getSymbolHandle() const {
         return _symbolsStyleDlg.getHSelf();
-    };
+    }
     void setTabName(int index, const wchar_t *name2set) {
         _ctrlTab.renameTab(index, name2set);
-    };
+    }
 protected :
     intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
 private :
@@ -373,11 +373,11 @@ private :
         ::GetWindowRect(_hSelf, &_dlgPos);
         _dlgPos.right -= _dlgPos.left;
         _dlgPos.bottom -= _dlgPos.top;
-    };
-    void restorePosSize(){reSizeTo(_dlgPos);};
+    }
+    void restorePosSize(){ reSizeTo(_dlgPos); }
     void enableLangAndControlsBy(size_t index);
 protected :
-    void setKeywords2List(int) override {};
+    void setKeywords2List(int) override {}
     void updateDlg() override;
 };
 
@@ -396,19 +396,19 @@ public :
 		{
 			_restrictedChars = restrictedChars;
 		}
-	};
+	}
 
     intptr_t doDialog() {
-        return ::DialogBoxParam(_hInst, MAKEINTRESOURCE(IDD_STRING_DLG), _hParent,  dlgProc, reinterpret_cast<LPARAM>(this));
-    };
+        return StaticDialog::myCreateDialogBoxIndirectParam(IDD_STRING_DLG, false);
+    }
 
-    void destroy() override {};
+    void destroy() override {}
 	
 protected :
     intptr_t CALLBACK run_dlgProc(UINT Message, WPARAM wParam, LPARAM) override;
 
 	// Custom proc to subclass edit control
-	LRESULT static CALLBACK customEditProc(HWND hEdit, UINT msg, WPARAM wParam, LPARAM lParam);
+	static LRESULT CALLBACK CustomEditProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam, UINT_PTR uIdSubclass, DWORD_PTR dwRefData);
 
 	bool isAllowed(const std::wstring& txt);
 	void HandlePaste(HWND hEdit);
@@ -420,35 +420,36 @@ private :
 	std::wstring _restrictedChars;
     int _txtLen = 0;
 	bool _shouldGotoCenter = false;
-	WNDPROC _oldEditProc = nullptr;
 };
 
-class StylerDlg
+class StylerDlg : public StaticDialog
 {
 public:
-    StylerDlg( HINSTANCE hInst, HWND parent, int stylerIndex = 0, int enabledNesters = -1):
-        _hInst(hInst), _parent(parent), _stylerIndex(stylerIndex), _enabledNesters(enabledNesters) {
+    StylerDlg(HINSTANCE hInst, HWND parent, int stylerIndex = 0, int enabledNesters = -1):
+        _stylerIndex(stylerIndex), _enabledNesters(enabledNesters) {
+        Window::init(hInst, parent);
         _pFgColour = new ColourPicker;
         _pBgColour = new ColourPicker;
         _initialStyle = SharedParametersDialog::_pUserLang->_styles.getStyler(stylerIndex);
-    };
+    }
 
-    ~StylerDlg() {
+    ~StylerDlg() override {
         _pFgColour->destroy();
         _pBgColour->destroy();
         delete _pFgColour;
         delete _pBgColour;
-	};
+    }
 
-    long doDialog() {
-		return long(::DialogBoxParam(_hInst, MAKEINTRESOURCE(IDD_STYLER_POPUP_DLG), _parent, dlgProc, reinterpret_cast<LPARAM>(this)));
-    };
+    void destroy() override {}
 
-    static intptr_t CALLBACK dlgProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam);
+    int doDialog() {
+        return static_cast<int>(StaticDialog::myCreateDialogBoxIndirectParam(IDD_STYLER_POPUP_DLG, false));
+    }
+
+protected:
+    intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
 
 private:
-    HINSTANCE _hInst = nullptr;
-    HWND _parent = nullptr;
     int _stylerIndex = 0;
     int _enabledNesters = 0;
     ColourPicker * _pFgColour = nullptr;
