@@ -62,7 +62,7 @@
     #define IDC_SAVECLOSE_BUTTON	(IDD_GLOBAL_STYLER_DLG + 1)
     #define IDC_SC_PERCENTAGE_SLIDER     (IDD_GLOBAL_STYLER_DLG + 2)
 	#define IDC_SC_TRANSPARENT_CHECK    (IDD_GLOBAL_STYLER_DLG + 3)
-	#define IDC_LANGUAGES_LIST   (IDD_GLOBAL_STYLER_DLG + 4)
+	#define IDC_LANGUAGES_COMBO   (IDD_GLOBAL_STYLER_DLG + 4)
 	#define IDC_STYLES_LIST       (IDD_GLOBAL_STYLER_DLG + 5)
 	#define IDC_SWITCH2THEME_STATIC       (IDD_GLOBAL_STYLER_DLG + 6)
 	#define IDC_SWITCH2THEME_COMBO       (IDD_GLOBAL_STYLER_DLG + 7)
