@@ -33,9 +33,10 @@ struct TaskLstFnStatus {
 	int _status = 0;
 	void *_bufID = nullptr;
 	int _docColor = -1;
-	TaskLstFnStatus(const std::wstring& str, int status) : _fn(str), _status(status){};
-	TaskLstFnStatus(int iView, int docIndex, std::wstring str, int status, void *bufID, int docColor) : 
-	_iView(iView), _docIndex(docIndex), _fn(str), _status(status), _bufID(bufID), _docColor(docColor) {};
+	TaskLstFnStatus(const std::wstring& str, int status) : _fn(str), _status(status) {}
+	TaskLstFnStatus(int iView, int docIndex, std::wstring str, int status, void* bufID, int docColor)
+		: _iView(iView), _docIndex(docIndex), _fn(str), _status(status), _bufID(bufID), _docColor(docColor)
+	{}
 };
 
 struct TaskListInfo {
@@ -46,14 +47,14 @@ struct TaskListInfo {
 class TaskListDlg : public StaticDialog
 {
 public :
-		TaskListDlg() : StaticDialog() { _instanceCount++; };
-		void init(HINSTANCE hInst, HWND parent, HIMAGELIST hImgLst, bool dir) {
-            Window::init(hInst, parent);
-			_hImalist = hImgLst;
-			_initDir = dir;
-        };
-        int doDialog(bool isRTL = false);
-		void destroy() override {};
+	TaskListDlg() : StaticDialog() { _instanceCount++; }
+	void init(HINSTANCE hInst, HWND parent, HIMAGELIST hImgLst, bool dir) {
+		Window::init(hInst, parent);
+		_hImalist = hImgLst;
+		_initDir = dir;
+	}
+	int doDialog(bool isRTL = false);
+	void destroy() override {}
 
 protected :
 	intptr_t CALLBACK run_dlgProc(UINT Message, WPARAM wParam, LPARAM lParam) override;
