@@ -25,7 +25,7 @@ class RunMacroDlg : public StaticDialog
 {
 public :
 	RunMacroDlg() = default;
-	~RunMacroDlg() = default;
+	~RunMacroDlg() override = default;
 
 	void doDialog(bool isRTL = false) {
 		if (!isCreated())
@@ -38,12 +38,12 @@ public :
 			::ShowWindow(_hSelf, SW_SHOW);
 			::SendMessageW(_hSelf, DM_REPOSITION, 0, 0);
 		}
-	};
+	}
 
 	void initMacroList();
 
-	int isMulti() const { return isCheckedOrNot(IDC_M_RUN_MULTI); };
-	int getTimes() const {return _times;};
+	int isMulti() const { return isCheckedOrNot(IDC_M_RUN_MULTI); }
+	int getTimes() const { return _times; }
 	int getMacro2Exec() const;
 
 private :
