@@ -36,7 +36,6 @@
 #include "CellBuffer.h"
 #include "CharClassify.h"
 #include "Decoration.h"
-#include "ILexer.h"
 #include "CaseFolder.h"
 #include "CharacterCategoryMap.h"
 #include "Document.h"
@@ -44,8 +43,17 @@
 #include "UTF8DocumentIterator.h"
 #include "AnsiDocumentIterator.h"
 #include "BoostRegexSearch.h"
+
+#if defined(__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wconversion"
+#endif
 #include <boost/regex.hpp>
 #include <boost/throw_exception.hpp>
+#if defined(__GNUC__)
+#pragma GCC diagnostic pop
+#endif
+
 #define CP_UTF8 65001
 #define SC_CP_UTF8 65001
 
@@ -57,14 +65,14 @@ class BoostRegexSearch : public RegexSearchBase
 public:
 	BoostRegexSearch() {}
 
-	virtual ~BoostRegexSearch()
+	~BoostRegexSearch() override
 	{
 		delete[] _substituted;
 		_substituted = nullptr;
 	}
 
 	virtual Sci::Position FindText(Document* doc, Sci::Position minPos, Sci::Position maxPos, const char *regex,
-                        bool caseSensitive, bool word, bool wordStart, Scintilla::FindOption sciSearchFlags, Sci::Position *lengthRet) override;
+						bool caseSensitive, bool word, bool wordStart, Scintilla::FindOption sciSearchFlags, Sci::Position *lengthRet) override;
 
 	virtual const char *SubstituteByPosition(Document* doc, const char *text, Sci::Position *length) override;
 
@@ -74,8 +82,8 @@ private:
 	class Match : private DocWatcher {
 	public:
 		Match() : _document(NULL), _documentModified(false), _position(-1), _endPosition(-1), _endPositionForContinuationCheck(-1)  {}
-		~Match() { setDocument(NULL); }
-		Match(Document* document, Sci::Position position = -1, Sci::Position endPosition = -1) : _document(NULL) { set(document, position, endPosition); }
+		~Match() override { setDocument(NULL); }
+		explicit Match(Document* document, Sci::Position position = -1, Sci::Position endPosition = -1) : _document(NULL) { set(document, position, endPosition); }
 		Match& operator=(Match& m) {
 			set(m._document, m.position(), m.endPosition());
 			return *this;
@@ -92,7 +100,7 @@ private:
 			_documentModified = false;
 		}
 
-		bool isContinuationSearch(Document* document, Sci::Position startPosition, int direction) {
+		bool isContinuationSearch(const Document* document, Sci::Position startPosition, int direction) {
 			if (hasDocumentChanged(document))
 				return false;
 			if (direction > 0)
@@ -117,7 +125,7 @@ private:
 		}
 
 	private:
-		bool hasDocumentChanged(Document* currentDocument) {
+		bool hasDocumentChanged(const Document* currentDocument) {
 			return currentDocument != _document || _documentModified;
 		}
 		void setDocument(Document* newDocument) {
@@ -132,7 +140,7 @@ private:
 		}
 
 		// DocWatcher, so we can track modifications to know if we should consider a search to be a continuation of last search:
-		virtual void NotifyModified(Document* modifiedDocument, DocModification mh, void* /*userData*/)
+		void NotifyModified(Document* modifiedDocument, DocModification mh, void* /*userData*/) override
 		{
 			if (modifiedDocument == _document)
 			{
@@ -154,7 +162,7 @@ private:
 			}
 		}
 
-		virtual void NotifyDeleted(Document* deletedDocument, void* /*userData*/) noexcept
+		void NotifyDeleted(Document* deletedDocument, void* /*userData*/) noexcept override
 		{
 			if (deletedDocument == _document)
 			{
@@ -165,12 +173,12 @@ private:
 				set(NULL);
 			}
 		}
-		virtual void NotifyModifyAttempt(Document* /*document*/, void* /*userData*/) {}
-		virtual void NotifySavePoint(Document* /*document*/, void* /*userData*/, bool /*atSavePoint*/) {}
-		virtual void NotifyStyleNeeded(Document* /*document*/, void* /*userData*/, Sci::Position /*endPos*/) {}
+		void NotifyModifyAttempt(Document* /*document*/, void* /*userData*/) override {}
+		void NotifySavePoint(Document* /*document*/, void* /*userData*/, bool /*atSavePoint*/) override {}
+		void NotifyStyleNeeded(Document* /*document*/, void* /*userData*/, Sci::Position /*endPos*/) override {}
 		virtual void NotifyLexerChanged(Document* /*document*/, void* /*userData*/) {}
-		virtual void NotifyErrorOccurred(Document* /*document*/, void* /*userData*/, Scintilla::Status /*status*/) {}
-		virtual void NotifyGroupCompleted(Document* /*document*/, void* /*userData*/) noexcept {}
+		void NotifyErrorOccurred(Document* /*document*/, void* /*userData*/, Scintilla::Status /*status*/) override {}
+		void NotifyGroupCompleted(Document* /*document*/, void* /*userData*/) noexcept override {}
 
 		Document* _document;
 		bool _documentModified;
@@ -180,7 +188,7 @@ private:
 
 	class CharTPtr { // Automatically translatable from utf8 to wchar_t*, if required, with allocation and deallocation on destruction; char* is not deallocated.
 	public:
-		CharTPtr(const char* ptr) : _charPtr(ptr), _wcharPtr(NULL) {}
+		explicit CharTPtr(const char* ptr) : _charPtr(ptr), _wcharPtr(NULL) {}
 		~CharTPtr() {
 			delete[] _wcharPtr;
 		}
@@ -270,7 +278,7 @@ std::string g_exceptionMessage;
  */
 
 Sci::Position BoostRegexSearch::FindText(Document* doc, Sci::Position startPosition, Sci::Position endPosition, const char *regexString,
-                        bool caseSensitive, bool /*word*/, bool /*wordStart*/, Scintilla::FindOption sciSearchFlags, Sci::Position *lengthRet)
+						bool caseSensitive, bool /*word*/, bool /*wordStart*/, Scintilla::FindOption sciSearchFlags, Sci::Position *lengthRet)
 {
 	g_exceptionMessage.clear();
 	try {
@@ -318,7 +326,7 @@ Sci::Position BoostRegexSearch::FindText(Document* doc, Sci::Position startPosit
 
 		Match match =
 			isUtf8 ? _utf8.FindText(search)
-			       : _ansi.FindText(search);
+				   : _ansi.FindText(search);
 
 		if (match.found())
 		{
@@ -464,7 +472,7 @@ const char *BoostRegexSearch::SubstituteByPosition(Document* doc, const char *te
 
 template <class CharT, class CharacterIterator>
 char *BoostRegexSearch::EncodingDependent<CharT, CharacterIterator>::SubstituteByPosition(const char *text, Sci::Position *length) {
-	char *substituted = stringToCharPtr(_match.format((const CharT*)CharTPtr(text), boost::format_all));
+	char *substituted = stringToCharPtr(_match.format(static_cast<const CharT*>(CharTPtr(text)), boost::format_all));
 	*length = static_cast<int>(strlen(substituted));
 	return substituted;
 }
@@ -500,4 +508,4 @@ char *BoostRegexSearch::stringToCharPtr(const std::string& str)
 char *BoostRegexSearch::stringToCharPtr(const std::wstring& str)
 {
 	return wcharToUtf8(str.c_str());
-}
\ No newline at end of file
+}
